// SPDX-License-Identifier: LGPL-3.0-or-later
/*
 * ZIO-specific configuration (mostly device-independent)
 *
 * Copyright (C) 2016 CERN (www.cern.ch)
 * Author: Federico Vaga <federico.vaga@cern.ch>
 *
 * This header hold all the specificity for the FMC ADC 100M module
 */

#ifndef FMCADC100M14B_LIB_H_
#define FMCADC100M14B_LIB_H_

#ifdef __cplusplus
#pragma GCC diagnostic ignored "-Wwrite-strings"
extern "C" {
#endif

#include "adc-lib.h"

#define ADC_CONF_100M14B4CHA_CHN_RANGE_N 3
/**
 * List of known voltage ranges to be used with the configuration option
 * ADC_CONF_CHN_RANGE
 */
enum adc_configuration_100m14b4cha_channel_range {
	ADC_CONF_100M14B4CHA_CHN_RANGE_OPEN_DRAIN= 0,
	ADC_CONF_100M14B4CHA_CHN_RANGE_100mV= 0x23,
	ADC_CONF_100M14B4CHA_CHN_RANGE_1V= 0x11,
	ADC_CONF_100M14B4CHA_CHN_RANGE_10V= 0x45,
	ADC_CONF_100M14B4CHA_CHN_RANGE_100mV_CAL= 0x42,
	ADC_CONF_100M14B4CHA_CHN_RANGE_1V_CAL= 0x40,
	ADC_CONF_100M14B4CHA_CHN_RANGE_10V_CAL= 0x44,
};


/**
 * It describes the possible configuration parameters for the
 * FMCADC100M14B4CHA card (ADC_CONF_TYPE_CUS)
 */
enum adc_configuration_100m14b4cha {
	ADC_CONF_100M14B4CHA_TRG_SW_EN, /**< software trigger enable/disable */
	ADC_CONF_100M14B4CHA_ACQ_MSHOT_MAX, /**< Maximum size for a single shot
					     in multi-shot mode (in samples) */
	ADC_CONF_100M14B4CHA_BUF_SIZE_KB, /**< it manually sets the buffer size but
					     only for VMALLOC buffers */
	ADC_CONF_100M14B4CHA_BUF_SIZE_LEN,  /**< it manually sets the buffer
					       length, but only for KMALLOC
					       buffers */
	__ADC_CONF_100M14B4CHA_LAST_INDEX, /**< It represents the the last index
					     of this enum. It can be useful for
					     some sort of automation */
};


#ifdef __cplusplus
}
#endif

#endif /* FMCADC_LIB_H_ */
